@@ -46,6 +46,7 @@ from falcon_toolkit.common.console_utils import build_file_hyperlink
 from falcon_toolkit.common.logging_config import configure_logger
 from falcon_toolkit.common.utils import configure_data_dir
 from falcon_toolkit.hosts.cli import cli_host_search
+from falcon_toolkit.policies.cli import cli_policies
 from falcon_toolkit.shell.cli import cli_shell
 
 
@@ -222,6 +223,7 @@ def cli_list_filters():
 
 
 # Load all commands into the main cli object, ready for use as root falcon commands
-cli.add_command(cli_shell)
 cli.add_command(cli_host_search)
 cli.add_command(cli_list_filters)
+cli.add_command(cli_policies)
+cli.add_command(cli_shell)
